from flask import render_template
from flask import request
from flask import jsonify
from app import app

from app.pig_latin_translation import translate_text

@app.route('/')
@app.route('/index')
def index():
    return render_template('index.html')

@app.route('/api/translate', methods=['POST'])
def translate():
    return jsonify({
        'text' : translate_text(request.form['text']),})


from distutils.core import setup

setup(
    name='PigLatinTranslation',
    version='0.1',
    include_package_data=True,
    url='https://github.com/Jai-Chaudhary/pig-latin-translation-microservice',
    license='MIT',
    author='Jai Chaudhary',
    author_email='jai.chaudhary.ittd@gmail.com',
    packages=['app',],
    long_description=__doc__,
    description='A Pig Latin Translation Microservice',
)


import re

VOWELS = ('a', 'e', 'i', 'o', 'u')
VOWEL_SND_SUFFIX = "yay"
CONSONANT_SND_SUFFIX = "ay"

def translate_text(input_text):
  text_translation = []

  for match in re.finditer("(?P<not_word>\W+)|(?P<word>[\w']+)", input_text):
    if match.group("word") == None:
      text_translation.append(match.group("not_word"))
    else:
      translated_word = translate_word(match.group("word"))
      translated_word = proper_case(match.group("word"), translated_word)
      text_translation.append(translated_word)
  return "".join(text_translation)

def translate_word(word):
  assert(len(word) > 0)

  word = word.lower()

  if word[0] in VOWELS:
    return word + VOWEL_SND_SUFFIX
  else:
    for idx, char in enumerate(word):
      if char in VOWELS:
        return word[idx:] + word[:idx] + CONSONANT_SND_SUFFIX
    return word + CONSONANT_SND_SUFFIX

def proper_case(word, translated_word):
  if word.title() == word:
    return translated_word.title()

  return translated_word
